;PHASE VOCODER ORCHESTRA
;LEE ZAKIAN	5/29/2003 9:01:33 AM

sr 		= 44100
kr 		= 4410
ksmps 		= 10
nchnls 		= 2
zakinit   	10, 10

/*
Two phase vocoder instruments, to cross-synthesize 2, 3, or 4 analysed samples. 
Each instrument has a .pvc file(s) sent through the opcodes PVBUFREAD and PVCROSS.

===CONFIGURATIONS
1.) 2 samples:	One analyzed sample in each instrument
2.) 3 samples:	One analyzed samples in Instr 1, two analyzed samples in Instr 2
3.) 4 samples:	Two analyzed samples in each instrument

===AMPLITUDE
"kamp" controls the dynamic level
Set to 0 to mute
Set to 1 for no change
Use "LINE" to create a gradual crescendo or decrescendo
Use "LINSEG" for varied amplitude

===PITCH
"ifmod" is used to tune instrument 1 to instrument 2
Set to 1 for no change
Set from >1 to 2 to raise the pitch up to 1 octave
Set from <1 to .5 to lower the pitch up to 1 octave
Use "CPSPCH" to designate transposition by steps

"kfmod" is used for variable pitch changes
Use "LINE" for gradual pitch change
Use "LINSEG" for varied pitch

===TIME
"ktime" is used to change  the tempo of the analyzed samples
Using "LINE", a value equal to the sample length will play it unchanged
Using "LINE", a value > the sample length makes it play faster
Using "LINE", a value < than the sample length makes it play slower

Using the ZAK system, .pvc files go through EQ and REVERB instruments,
and out a mixer. Several panning options  are explained in the mixer instrument.
The EQ instrument is especially helpful if the phase vocoder process has altered the
audio spectrum in an unsatisfactory way. The EQ and REVERB instruments may be
bypassed if the iout arguments in the phase vocoder instruments are set to the input
channels of the mixer.
*/
  
	instr     1	;Mozart Minuet
	
/*
W. A. Mozart
Symphony #18  K. 130
1772
Excerpt From Minuet, 4 measures looped
C Major, 3/4 Time, 126 bpm
*/
			
iout		=	p4
				;kamp 1 ( ktime 1)		
				;crescendo/decrescendo			mute		mute					
kamp1  	linseg		0, p3/8, .9, p3/8, .7, p3/8, .3, p3/8, 0, 	p3/8, 0, 	p3/8, 0, p3/8, 0, p3/8, 0 
   
 				;kamp 2 (ktime 2)						
				;mute					mute		;crescendo/decrescendo
kamp2  	linseg		0, p3/8, 0, p3/8, 0, p3/8, 0, p3/8, 0, 	p3/8, 0, 	p3/8, .9, p3/8, .1, p3/8, 0

ifmod     	= 		cpspch(8.00)/cpspch(7.10) ;up 2 half steps to D

				;Sample 156 seconds, playing slower, at 2 different speeds
					;156=no change, < 156=slower, > 156=faster 
ktime1    	line      		0, 156, 	89.7	
ktime2    	line      		0, 156, 	90.75	;slightly faster than ktime1

          		pvbufread 	ktime1, "Mozart2.pvc"
apvc      	pvcross   	ktime2, ifmod, "Mozart2.pvc", kamp1, kamp2
		zawm       	apvc, iout
          	endin

	instr     2	;Hey Jude
	
/*
J. Lennnon, P. McCartney
Hey Jude
1968
Coda, 4 measures repeated
F Major, 4/4 Time, 72 bpm
*/

iout	=	p4
				;crescendo/decrescendo
kamp1 		linseg		0, p3/5, .05, p3/5, .3, p3/5, .2, p3/5, .15, p3/5, 0
kamp2	 	linseg		0, p3/5, .05, p3/5, .3, p3/5, .2, p3/5, .15, p3/5, 0

ifmod     	=		cpspch(8.00)/cpspch(8.03) ;down 3 half steps to D
				
				;Sample 156 seconds, playing faster
					;156=no change, < 156=slower, > 156=faster
ktime1    	line      		0, 156, 	210
ktime2    	line      		0, 156, 	210

          		pvbufread	ktime1, "Jude2.pvc"
apvc  	    	pvcross   	ktime2, ifmod, "Jude2.pvc", kamp1, kamp2
          		zawm       		apvc, iout
          endin

	instr   93 	;EQ: Mozart Minuet

ilg1 		=	p4	;low gain1
ilg2 		=	p5	;low gain2
img 		=      	p6	;mid gain      
ihg1 		=       	p7	;high gain1
ihg2		=	p8	;high gain2
	
iin		=	p9
iout		=	p10
				;Vary frequencies in score table (f3)
ilc1		table	0, 3	;200 Hz	
ilc2		table	1, 3	;500 Hz	
ihc1		table	2, 3	;2000 Hz
ihc2		table	3, 3	;4000 Hz

asig		zar		iin

alsig1		butterlp	asig, ilc1		;low cut 1
alsig2		butterlp 	asig, ilc2	     	;low cut 2
atemp	 	butterhp 	asig, ilg2-ilc2/4		;mid range temp
amsig 		butterlp 	atemp, ihg1+ihc1/4	;mid cut
ahsig1 		butterhp 	asig, ihc1	      	;high cut 1
ahsig2 		butterhp 	asig, ihc2		;high cut 2

aout		mac		ilg1, alsig1, ilg2, alsig2, img, amsig, ihg1, ahsig1, ihg2, ahsig2	
		zawm		aout, iout
	endin

instr   94 	;EQ: Hey Jude

ilg1 		=	p4	;low gain1
ilg2 		=	p5	;low gain2
img 		=      	p6	;mid gain      
ihg1 		=       	p7	;high gain1
ihg2		=	p8	;high gain2
	
iin		=	p9
iout		=	p10
				;Vary frequencies in score table (f4)
ilc1		table	0, 4	;300 Hz	
ilc2		table	1, 4	;1000 Hz
ihc1		table	2, 4	;2500 Hz
ihc2		table	3, 4	;7000 Hz

asig		zar		iin

alsig1		butterlp	asig, ilc1		;low cut 1
alsig2		butterlp 	asig, ilc2	     	;low cut 2
atemp	 	butterhp 	asig, ilg2-ilc2/4		;mid range temp
amsig 		butterlp 	atemp, ihg1+ihc1/4	;mid cut
ahsig1 		butterhp 	asig, ihc1	      	;high cut 1
ahsig2 		butterhp 	asig, ihc2		;high cut 2

aout		mac		ilg1, alsig1, ilg2, alsig2, img, amsig, ihg1, ahsig1, ihg2, ahsig2	
		zawm		aout, iout
	endin

	instr 98		;REVERB
			;Mozart Minuet Left, Hey Jude Right
iinL		=	p4
iinR		=	p5
ioutL		=	p6
ioutR		=	p7	
irvbtimeL	=	p8
irvbtimeR	=	p9	
iwetL		=	p10
idryL		=	1-p10
iwetR		=	p11
idryR		=	1-p11
ihfrollL	=	p12	;low pass filter: high frequency rolloff
ihfrollR	=	p13
ihfdiffL	=	p14	;high frequency diffusion
ihfdiffR	=	p15
asigL		zar	iinL
asigR		zar	iinR
aoutrevL	nreverb	asigL*iwetL, p8, p14
aoutrevR	nreverb	asigR*iwetR, p9, p15
aoutL		tone	aoutrevL, p12
aoutR		tone	aoutrevR, p13
		zawm	(aoutL+(asigL*idryL)),ioutL
		zawm	(aoutR+(asigR*idryR)), ioutR	
	endin

	instr 100	;MIXER

/*
	3 PANNING OPTIONS

===Single Location	1 to 0
kpanL		=	1 			pan hard left 
kpanlR		=	0 			pan hard right

===Movement In One Direction
kpanL		line	0, p3, 1 	 	pan right to left
kpanR		line	1, p3, 0			pan left to right

===Movement In Multiple Directions
kpanL		linseg	1, p3/2, 0, p3/2, 1	pan left to right to left
kpanR		linseg	0, p3/2, 1, p3/2, 0	pan right to left to right
*/
 
;++CHANNEL 1	Mozart Minuet
a1		zar	p4	;IN
igL		init	p5	;GAIN
kpanL		linseg	.6, p3/5, .2, p3/5, 0, p3/5, .3, p3/5, .5, p3/5, .7	;PAN
						
;=====
;++CHANNEL 2	Hey Jude
a2		zar	p6	;IN
igR		init	p7	;GAIN
kpanR		linseg	.4, p3/5, .8, p3/5, 1, p3/5, .7, p3/5, .5, p3/5, .3	;PAN

aoutL		=	((igL*a1)*(kpanL))+((igL*a2)*(1-kpanL))
aoutR		=	((igR*a1)*(kpanR))+((igR*a2)*(1-kpanR))
		outs	aoutL, aoutR
		zacl	0, 10
		endin

